
Dromi: Python package for parallel computation of similarity measures among vector-encoded sequences

- Installing:

``
pip install dromi
``

-Usage/Example: See ``Dromi_example.py``


- Reference:

```
@article{sanz2023dromi,
  title={Dromi: Python package for parallel computation of similarity measures among vector-encoded sequences},
  author={Sanz Moreta, Lys},
  journal={bioRxiv},
  pages={2023--07},
  year={2023},
  publisher={Cold Spring Harbor Laboratory}
}
```